@@ -6,11 +6,11 @@ analyze mydesign.vhdl
 elab myentity
 
 if c_compiler_is_available && ghdl_has_feature myentity vpi; then
-  $GHDL --vpi-compile -v gcc -c vpi1.c
-  $GHDL --vpi-link -v gcc -o vpi1.vpi vpi1.o
+  $GHDL --vpi-compile -v $CC -c vpi1.c
+  $GHDL --vpi-link -v $CC -o vpi1.vpi vpi1.o
 
-  $GHDL --vpi-compile -v gcc -c vpi2.c
-  $GHDL --vpi-link -v gcc -o vpi2.vpi vpi2.o
+  $GHDL --vpi-compile -v $CC -c vpi2.c
+  $GHDL --vpi-link -v $CC -o vpi2.vpi vpi2.o
 
   add_vpi_path
 
